// Copyright (C) 2017, Rory Bradford <rory@dysfunctionalprogramming.com>
// MIT License

#include <node.h>

#if defined(_WIN32)
  #include <windows.h>
#else
  #include <unistd.h>
#endif

namespace sleepsync {

void sleep(const v8::FunctionCallbackInfo<v8::Value>& args) {
  v8::Isolate* isolate = args.GetIsolate();

  if (!args[0]->IsNumber()) {
    v8::Local<v8::String> msg = v8::String::NewFromUtf8(isolate,
      "Argument must be a number.");
    isolate->ThrowException(v8::Exception::TypeError(msg));
    return;
  }

#if defined(_WIN32)
  Sleep(args[0]->NumberValue() * 1000);
#else
  usleep(args[0]->NumberValue() * 1000);
#endif
}

}  // namespace sleepsync

void Init(v8::Local<v8::Object> exports, v8::Local<v8::Object> module) {
  NODE_SET_METHOD(module, "exports", sleepsync::sleep);
}

NODE_MODULE(addon, Init)
